package com.ruoyi.web.controller.aliexpress;

import com.global.iop.api.IopClient;
import com.global.iop.api.IopClientImpl;
import com.global.iop.api.IopRequest;
import com.global.iop.api.IopResponse;
import com.global.iop.domain.Protocol;
import com.global.iop.util.ApiException;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.controller.aliexpress.dto.token.TokenTokenCreateDTO;
import com.ruoyi.web.controller.aliexpress.dto.token.TokenTokenRefreshDTO;
import com.ruoyi.web.controller.aliexpress.dto.token.TokenTokenSecurityCreateDTO;
import com.ruoyi.web.controller.aliexpress.dto.token.TokenTokenSecurityRefreshDTO;
import com.ruoyi.web.core.config.AliexpressAuthClientConfig;
import com.ruoyi.web.enumerate.AliexpressTokenEnu;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * @author ldj
 * @date 2024/2/29 18:19
 * @Description: ...
 * @Version 1.0
 */
@RestController
@Api("对接速卖通 token")
@RequestMapping("/aliexpress/token")
public class AliexpressTokenController {

    @Resource
    private AliexpressAuthClientConfig AliexpressAuthClientConfig;

    //为调用 API 安全生成access_token
    //为调用 API 安全生成access_token
    /*
IopClient client = new IopClient(url, appkey, appSecret);
IopRequest request = new IopRequest();
request.setApiName("/auth/token/security/create");
request.addApiParameter("code", "0_2DL4DV3jcU1UOT7WGI1A4rY91");
request.addApiParameter("uuid", "uuid");
IopResponse response = client.execute(request, Protocol.GOP);
System.out.println(response.getBody());
Thread.sleep(10);
     */

    /**
     * 安全生成access_token
     */
    @Log(title = "安全生成access_token", businessType = BusinessType.SELECT)
    @ApiOperation("安全生成access_token")
    @PostMapping("/tokenSecurityCreate")
    public String tokenSecurityCreate(@RequestBody TokenTokenSecurityCreateDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressTokenEnu.TOKEN_SECURITY_CREATE.getApiName());
        request.addApiParameter("code", reqDto.getCode());
        request.addApiParameter("uuid", reqDto.getUuid());
        IopResponse response = client.execute(request, Protocol.TOP);
        return response.getGopResponseBody();
    }

    //生成调用api的access_token
    //生成调用api的access_token
    /*
IopClient client = new IopClient(url, appkey, appSecret);
IopRequest request = new IopRequest();
request.setApiName("/auth/token/create");
request.addApiParameter("code", "0_2DL4DV3jcU1UOT7WGI1A4rY91");
request.addApiParameter("uuid", "uuid");
IopResponse response = client.execute(request, Protocol.GOP);
System.out.println(response.getBody());
Thread.sleep(10);
     */

    /**
     * 生成access_token
     */
    @Log(title = "生成access_token", businessType = BusinessType.SELECT)
    @ApiOperation("生成access_token")
    @PostMapping("/tokenCreate")
    public String tokenCreate(@RequestBody TokenTokenCreateDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressTokenEnu.TOKEN_CREATE.getApiName());
        request.addApiParameter("code", reqDto.getCode());
        request.addApiParameter("uuid", reqDto.getUuid());
        IopResponse response = client.execute(request, Protocol.TOP);
        return response.getGopResponseBody();
    }
    //安全刷新access_token
    //描述：刷新access_token安全地进行 API 调用
    /*
IopClient client = new IopClient(url, appkey, appSecret);
IopRequest request = new IopRequest();
request.setApiName("/auth/token/security/refresh");
request.addApiParameter("refresh_token", "50001600212wcwiOabwyjtEH11acc19aBOvQr9ZYkYDlr987D8BB88LIB8bj");
IopResponse response = client.execute(request, Protocol.GOP);
System.out.println(response.getBody());
Thread.sleep(10);
     */

    /**
     * 安全刷新access_token
     */
    @Log(title = "安全刷新access_token", businessType = BusinessType.SELECT)
    @ApiOperation("安全刷新access_token")
    @PostMapping("/tokenSecurityRefresh")
    public String tokenSecurityRefresh(@RequestBody TokenTokenSecurityRefreshDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressTokenEnu.TOKEN_SECURITY_REFRESH.getApiName());
        request.addApiParameter("refresh_token", reqDto.getRefresh_token());
        IopResponse response = client.execute(request, Protocol.TOP);
        return response.getGopResponseBody();
    }
    //刷新access_token
    //刷新access_token，端点 https://api-sg.aliexpress.com/rest
    /*
IopClient client = new IopClient(url, appkey, appSecret);
IopRequest request = new IopRequest();
request.setApiName("/auth/token/refresh");
request.addApiParameter("refresh_token", "50001600212wcwiOabwyjtEH11acc19aBOvQr9ZYkYDlr987D8BB88LIB8bj");
IopResponse response = client.execute(request, Protocol.GOP);
System.out.println(response.getBody());
Thread.sleep(10);
     */

    /**
     * 刷新access_token
     */
    @Log(title = "刷新access_token", businessType = BusinessType.SELECT)
    @ApiOperation("刷新access_token")
    @PostMapping("/tokenRefresh")
    public String tokenRefresh(@RequestBody TokenTokenRefreshDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressTokenEnu.TOKEN_REFRESH.getApiName());
        request.addApiParameter("refresh_token", reqDto.getRefresh_token());
        IopResponse response = client.execute(request, Protocol.TOP);
        return response.getGopResponseBody();
    }
}
